@@ -2,10 +2,9 @@ use odbc_sys::{len_data_at_exec, CDataType, DATA_AT_EXEC};
 
 use crate::{
     handles::{DelayedInput, HasDataType, Statement},
-    DataType, Error, Parameter,
+    DataType, Error, ParameterRef,
 };
 use std::{
-    convert::TryInto,
     ffi::c_void,
     fs::File,
     io::{self, BufRead, BufReader},
@@ -90,13 +89,13 @@ impl HasDataType for BlobParam<'_> {
     }
 }
 
-unsafe impl Parameter for &mut BlobParam<'_> {
-    unsafe fn bind_parameter(
-        self,
+unsafe impl ParameterRef for &mut BlobParam<'_> {
+    unsafe fn bind_to(
+        &mut self,
         parameter_number: u16,
         stmt: &mut impl Statement,
     ) -> Result<(), Error> {
-        stmt.bind_delayed_input_parameter(parameter_number, self)
+        stmt.bind_delayed_input_parameter(parameter_number, *self)
             .into_result(stmt)
     }
 }
